@@ -7,7 +7,7 @@ require_once('admin-header.php');
 ?>
 
 <?php if ( isset($_GET['saved']) ) : ?>
-<div id="message" class="updated fade"><p><strong><?php _e('Page saved.') ?> <a href="edit-pages.php"><?php _e('Manage pages'); ?> &raquo;</a></strong></p></div>
+<div id="message" class="updated fade"><p><strong><?php _e('Page saved.') ?></strong> <a href="edit-pages.php"><?php _e('Manage pages'); ?></a> | <a href="<?php echo get_page_link( $_GET['saved'] ); ?>"><?php _e('View page'); ?> &raquo;</a></p></div>
 <?php endif; ?>
 
 <?php
@@ -20,4 +20,4 @@ if ( current_user_can('edit_pages') ) {
 }
 ?>
 
-<?php include('admin-footer.php'); ?> 
\ No newline at end of file
+<?php include('admin-footer.php'); ?>
