@@ -40,6 +40,12 @@ class wpdb {
 	//	DB Constructor - connects to the server and selects a database
 
 	function wpdb($dbuser, $dbpassword, $dbname, $dbhost) {
+		return $this->__construct($dbuser, $dbpassword, $dbname, $dbhost);
+	}
+	
+	function __construct($dbuser, $dbpassword, $dbname, $dbhost) {
+		register_shutdown_function(array(&$this, "__destruct"));
+
 		$this->dbh = @mysql_connect($dbhost, $dbuser, $dbpassword);
 		if (!$this->dbh) {
 			$this->bail("
@@ -57,6 +63,10 @@ class wpdb {
 		$this->select($dbname);
 	}
 
+	function __destruct() {
+		return true;		
+	}
+
 	// ==================================================================
 	//	Select a DB (if another one needs to be selected)
 
